def find_and_sum_multiples(maximum, number1, number2=None):

    if type(maximum) is not int or type(number1) is not int:
        raise TypeError("All parameters should be integers.")

    if number1 < 1:
        raise ValueError("The second parameter should be an integer with value 1 or higher.")

    if maximum < number1:
        raise ValueError("The first parameter should an integer that is equal to or higher than the second parameter.")

    if number2 is not None:
        if type(number2) is not int:
            raise TypeError("All parameters should be integers.")

        if number2 <= number1:
            raise ValueError("The third parameter should be an integer that is bigger than the second parameter.")

        if number2 > maximum:
            raise ValueError("The third parameter should be an integer that is smaller or equal to the first parameter")


    if number2 is None:
        sum_multiples = sum([number for number in range(number1, maximum) if number % number1 == 0])

    else:
        sum_multiples = sum([number for number in range(number1, maximum) if number % number1 == 0 or number % number2 == 0])

    print(sum_multiples)
    return sum_multiples





def sumevenfibonaccinumbers(startnumber, endvalue):

    if type(startnumber) not in [int, float] or type(endvalue) not in [int, float]:
        raise TypeError("Both parameters need to be integers or floats.")
    if startnumber < 0:
        raise ValueError("The first parameter should be a non-negative number.")
    if endvalue < startnumber:
        raise ValueError("The second parameter should be higher than the first parameter.")

    fibsequence = fibonaccisequence(startnumber)

    allfibnrsinrange = []
    allfibnrsinrange.extend(fibsequence[-2:])

    sumevenfibnrsinrange = 0
    for number in allfibnrsinrange:
        if number % 2 == 0 and number <= endvalue:
            sumevenfibnrsinrange += number

    i = sum(allfibnrsinrange[-2:])

    while i <= endvalue:
        if i % 2 == 0:
            sumevenfibnrsinrange += i

        allfibnrsinrange.extend([i])
        i = sum(allfibnrsinrange[-2:])

    print(sumevenfibnrsinrange)
    return sumevenfibnrsinrange


def fibonaccisequence(maxnumber):
    fibsequence = [0, 1]
    i = sum(fibsequence[-2:])

    while i < maxnumber:
        fibsequence.extend([i])
        i = sum(fibsequence[-2:])

    fibsequence.extend([i])
    i = sum(fibsequence[-2:])
    fibsequence.extend([i])

    return fibsequence




import unittest
from Problem01 import find_and_sum_multiples


class TestProblem01(unittest.TestCase):
    def test_function(self):
        self.assertEqual(find_and_sum_multiples(1000, 3, 5), 233168, "The result of the function does not match the expected result.")
        self.assertEqual(find_and_sum_multiples(10, 3), 18, "The result of the function does not match the expected result.")
        self.assertEqual(find_and_sum_multiples(10, 3, 5), 23, "The result of the function does not match the expected result.")


    def test_input_type(self):
        with self.assertRaises(TypeError):
            find_and_sum_multiples(5j, 3, 5)
            find_and_sum_multiples(1000, 2j, 8)
            find_and_sum_multiples(100, 2, 7j)
            find_and_sum_multiples("yes", 4, 7)
            find_and_sum_multiples(25, "no", 4)
            find_and_sum_multiples(250, 25, "None")


    def test_input_value(self):
        with self.assertRaises(ValueError):
            find_and_sum_multiples(-1, 2, 5)
            find_and_sum_multiples(-1, -3, -2)
            find_and_sum_multiples(10, 0, 8)
            find_and_sum_multiples(10, 11, 12)
            find_and_sum_multiples(1000, 3, 2)


if __name__ == '__main__':
    unittest.main()



from itertools import permutations
from functools import reduce
from math import sqrt, floor


def find_largest_pandigital_prime(min_digits, max_digits):
    if type(min_digits) is not int or type(max_digits) is not int:
        raise TypeError("Both parameters should be integers.")
    if min_digits < 1 or min_digits > 9 or max_digits < 1 or max_digits > 9:
        raise ValueError("The parameters should both be integers between 1 and 9.")
    if max_digits < min_digits:
        raise ValueError("The first parameter should be smaller than or equal to the second parameter.")

    largest_pandigital_prime = 0

    for nr_of_digits in reversed(range(min_digits, max_digits + 1)):
        if nr_of_digits not in [1, 2, 3, 5, 6, 8, 9]:
            set_of_required_digits = [str(i) for i in reversed(range(1, nr_of_digits + 1))]
            pandigital_numbers = permutations(set_of_required_digits)
            for number in pandigital_numbers:
                pandigital_number = int(reduce(lambda a, b: a+b, number))
                if is_prime_number(pandigital_number):
                    if pandigital_number > largest_pandigital_prime:
                        largest_pandigital_prime = pandigital_number

        if largest_pandigital_prime > 0:
            print(largest_pandigital_prime)
            return largest_pandigital_prime

    print("No prime pandigital found in the specified range.")
    return "NA"


def is_prime_number(number):
    max_factor = floor(sqrt(number)) + 1
    if number == 1:
        return False
    elif number == 2 or number == 3:
        return True
    else:
        for i in range(2, max_factor):
            if number % i == 0:
                return False
    return True



import unittest
from Problem02 import sumevenfibonaccinumbers

class TestSumRangeEvenFibNumbers(unittest.TestCase):
    def test_function(self):
        self.assertEqual(sumevenfibonaccinumbers(0, 0), 0, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(0, 1), 0, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(1, 1), 0, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(0, 2), 2, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(1, 9), 10, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(2, 9.5), 10, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(4.4, 19.1), 8, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(8, 8), 8, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(4, 12), 8, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(19, 60), 34, 'the result of the function does not match the expected result.')
        self.assertEqual(sumevenfibonaccinumbers(1, 4000000), 4613732, 'the result of the function does not match the expected result.')

    def test_input_type(self):
        with self.assertRaises(TypeError):
            sumevenfibonaccinumbers(5j, 5)
            sumevenfibonaccinumbers(1, 2j)
            sumevenfibonaccinumbers("yes", 5)
            sumevenfibonaccinumbers(1, "no")

    def test_input_value(self):
        with self.assertRaises(ValueError):
            sumevenfibonaccinumbers(-1, 2)
            sumevenfibonaccinumbers(1, 0)
            sumevenfibonaccinumbers(8, 2)
            sumevenfibonaccinumbers(2.6, -4.5)

if __name__ == '__main__':
    unittest.main()



import unittest
from Problem41 import find_largest_pandigital_prime, is_prime_number

class TestProblem41(unittest.TestCase):
    def test_main_function(self):
        self.assertEqual(find_largest_pandigital_prime(1, 9), 7652413, 'the result of the function does not match the expected result.')
        self.assertEqual(find_largest_pandigital_prime(1, 3), "NA", 'the result of the function does not match the expected result.')
        self.assertEqual(find_largest_pandigital_prime(5, 6), "NA", 'the result of the funtion does not match the expected result.')
        self.assertEqual(find_largest_pandigital_prime(8, 9), "NA", 'the result of the function does not match the expeced result.')
        self.assertEqual(find_largest_pandigital_prime(5, 7), 7652413, 'the result of the function does not match the expected result.')

    def test_input_type(self):
        with self.assertRaises(TypeError):
            find_largest_pandigital_prime(5j, 5)
            find_largest_pandigital_prime(1, 2j)
            find_largest_pandigital_prime("yes", 5)
            find_largest_pandigital_prime(1, "no")

    def test_input_value(self):
        with self.assertRaises(ValueError):
            find_largest_pandigital_prime(-1, 2)
            find_largest_pandigital_prime(1, 0)
            find_largest_pandigital_prime(8, 2)
            find_largest_pandigital_prime(1, 10)
            find_largest_pandigital_prime(0, 7)

    def test_is_prime_number_function(self):
        self.assertEqual(is_prime_number(1), False,'the result of the function does not match the expected result.')
        self.assertEqual(is_prime_number(2), True, 'the result of the function does not match the expected result.')
        self.assertEqual(is_prime_number(3), True, 'the result of the function does not match the expected result.')
        self.assertEqual(is_prime_number(4), False, 'the result of the function does not match the expected result.')
        self.assertEqual(is_prime_number(7919), True, 'the result of the function does not match the expected result.')
        self.assertEqual(is_prime_number(123456), False, 'the result of the function does not match the expected result.')
        self.assertEqual(is_prime_number(7652413), True, 'the result of the function does not match the expected result.')


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function

from glob import glob
from os.path import basename
from os.path import splitext

from setuptools import find_packages
from setuptools import setup

def read():
    with open("README.md", "r") as f:
        return f.read()


setup(
    name='gep_python_coding_challenge',
    version='0.0.4',
    license='MIT',
    description='This package contains the beginner level assignments of the GEP Python Coding Challenge.',
    long_description=read(),
    long_description_content_type="text/markdown",
    author='JcS',
    author_email='joyce@hey.com',
    url='https://github.com/Joyce-NL/gep-python-coding-challenge',
    py_modules=['Problem01', 'Problem02', 'Problem41'],
    package_dir={'': 'src'},
    zip_safe=False,
    classifiers=[
        # complete classifier list: http://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Other/Nonlisted Topic',
    ],
    keywords=[
        'Euler', 'Project Euler'
    ],
    python_requires='>=3.0',
    install_requires=[],
    extras_require={},
)
